@@ -13,10 +13,6 @@ import sys
 
 # Third party library imports ...
 from distutils.version import LooseVersion
-try:
-    import lxml.etree
-except ImportError:
-    pass
 import numpy as np
 
 # Local imports ...
@@ -24,7 +20,7 @@ from .lib import openjpeg as opj, openjp2 as opj2
 
 # Do not change the format of this next line!  Doing so risks breaking
 # setup.py
-version = "0.8.9"
+version = "0.8.10"
 _sv = LooseVersion(version)
 version_tuple = _sv.version
 
@@ -64,8 +60,11 @@ kwargs = {
     'numpy': np.__version__,
 }
 
-if 'lxml' in sys.modules.keys():
-    info += "lxml          {elxml}\n"
+try:
+    import lxml.etree
+    info += "lxml.etree    {elxml}\n"
     kwargs['elxml'] = lxml.etree.__version__
+except Exception:
+    pass
 
 info = info.format(**kwargs)
